@@ -176,6 +176,7 @@ def _get_options(ret):
         "abort_state_ids": None,
         "show_failed_states": False,
         "raw_version": False,
+        "fail_comment_length": None,
     }
     attrs = {
         "exe": "exe",
@@ -189,6 +190,7 @@ def _get_options(ret):
         "abort_state_ids": "abort_state_ids",
         "show_failed_states": "show_failed_states",
         "raw_version": "raw_version",
+        "fail_comment_length": "fail_comment_length",
     }
     _options = salt.returners.get_returner_options(
         __virtualname__,
@@ -361,10 +363,13 @@ def returner(ret):
         )
         for state_id, state_return in ret["return"].items():
             if state_return["result"] is False:
+                failed_comment = state_return.get("comment", "").replace('"', "").replace("\n", " ")
+                # pylint: disable=whitespace-before-colon
                 label_values = [
                     state_id.split("_|-")[1],
-                    state_return.get("comment", "").replace('"', "").replace("\n", " "),
+                    failed_comment[0 : opts["fail_comment_length"]],
                 ]
+                # pylint: enable=whitespace-before-colon
                 if opts["add_state_name"]:
                     label_values.append(prom_state)
                 gauge_show_failed_states.labels(*label_values).set(1)
@@ -378,7 +383,7 @@ def returner(ret):
         )
         gauge_salt_aborted.set(0)
         for state_id, state_return in ret["return"].items():
-            if not state_return["result"] and state_return["__id__"] in opts["abort_state_ids"]:
+            if not state_return["result"] and state_return.get("__id__") in opts["abort_state_ids"]:
                 gauge_salt_aborted.set(1)
 
     if opts["add_state_name"]:
@@ -404,17 +409,23 @@ def returner(ret):
                 label_values.append(__grains__["saltversion"].split("+", maxsplit=1)[0])
         keys_dict = output.pop(key)
         gauge_keys = Gauge(key, keys_dict["help"], labels, registry=registry)
-        if label_values:
-            gauge_keys.labels(*label_values).set(keys_dict["value"])
-        else:
-            gauge_keys.set(keys_dict["value"])
+        try:
+            if label_values:
+                gauge_keys.labels(*label_values).set(keys_dict["value"])
+            else:
+                gauge_keys.set(keys_dict["value"])
+        except ValueError:
+            keys_dict["value"] = keys_dict["value"].split("rc", maxsplit=1)[0]
+            if label_values:
+                gauge_keys.labels(*label_values).set(keys_dict["value"])
+            else:
+                gauge_keys.set(keys_dict["value"])
 
     write_to_textfile(opts["filename"], registry)
     if not salt.utils.platform.is_windows():
         salt.modules.file.chown(opts["filename"], opts["uid"], opts["gid"])
         if opts["mode"]:
             try:
-                opts["mode"] = int(opts["mode"], base=8)
                 salt.modules.file.set_mode(opts["filename"], opts["mode"])
             except ValueError:
                 opts["mode"] = None
